@@ -25,7 +25,7 @@ Schema:
             "num"               integer,
             "pkts":             integer,
             "bytes":            integer,  # converted based on suffix
-            "target":           string,
+            "target":           string,   # Null if blank
             "prot":             string,
             "opt":              string,   # "--" = Null
             "in":               string,
@@ -163,7 +163,7 @@ import jc.utils
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.8'
+    version = '1.9'
     description = '`iptables` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -222,6 +222,10 @@ def _process(proc_data):
                 if rule['opt'] == '--':
                     rule['opt'] = None
 
+            if 'target' in rule:
+                if rule['target'] == '':
+                    rule['target'] = None
+
     return proc_data
 
 
@@ -271,15 +275,18 @@ def parse(data, raw=False, quiet=False):
                 continue
 
             else:
+                # sometimes the "target" column is blank. Stuff in a dummy character
+                if headers[0] == 'target' and line.startswith(' '):
+                    line = '\u2063' + line
+
                 rule = line.split(maxsplit=len(headers) - 1)
                 temp_rule = dict(zip(headers, rule))
                 if temp_rule:
+                    if temp_rule.get('target') == '\u2063':
+                        temp_rule['target'] = ''
                     chain['rules'].append(temp_rule)
 
         if chain:
             raw_output.append(chain)
 
-    if raw:
-        return raw_output
-    else:
-        return _process(raw_output)
+    return raw_output if raw else _process(raw_output)
