@@ -1,7 +1,7 @@
 """jc - JSON Convert Proc file output parser
 
 This parser automatically identifies the Proc file and calls the
-corresponding parser to peform the parsing.
+corresponding parser to perform the parsing.
 
 Magic syntax for converting `/proc` files is also supported by running
 `jc /proc/<path to file>`. Any `jc` options must be specified before the
@@ -120,11 +120,12 @@ from jc.exceptions import ParseError
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.0'
+    version = '1.2'
     description = '`/proc/` file parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     compatible = ['linux']
+    tags = ['file']
 
 
 __version__ = info.version
@@ -153,6 +154,7 @@ def parse(
     if jc.utils.has_data(data):
         # signatures
         buddyinfo_p = re.compile(r'^Node \d+, zone\s+\w+\s+(?:\d+\s+){11}\n')
+        cmdline_p = re.compile(r'^BOOT_IMAGE=')
         consoles_p = re.compile(r'^\w+\s+[\-WUR]{3} \([ECBpba ]+\)\s+\d+:\d+\n')
         cpuinfo_p = re.compile(r'^processor\t+: \d+.*bogomips\t+: \d+.\d\d\n', re.DOTALL)
         crypto_p = re.compile(r'^name\s+:.*\ndriver\s+:.*\nmodule\s+:.*\n')
@@ -193,6 +195,7 @@ def parse(
         net_packet_p = re.compile(r'^sk       RefCnt Type Proto  Iface R Rmem   User   Inode\n')
         net_protocols_p = re.compile(r'^protocol  size sockets  memory press maxhdr  slab module     cl co di ac io in de sh ss gs se re sp bi br ha uh gp em\n')
         net_route_p = re.compile(r'^Iface\tDestination\tGateway \tFlags\tRefCnt\tUse\tMetric\tMask\t\tMTU\tWindow\tIRTT\s+\n')
+        net_tcp_p = re.compile(r'^\s+sl\s+local_address\s+(?:rem_address|remote_address)\s+st\s+tx_queue\s+rx_queue\s+tr\s+tm->when\s+retrnsmt\s+uid\s+timeout\s+inode')
         net_unix_p = re.compile(r'^Num       RefCount Protocol Flags    Type St Inode Path\n')
 
         pid_fdinfo_p = re.compile(r'^pos:\t\d+\nflags:\t\d+\nmnt_id:\t\d+\n')
@@ -201,15 +204,16 @@ def parse(
         pid_mountinfo_p = re.compile(r'^\d+ \d+ \d+:\d+ /.+\n')
         pid_numa_maps_p = re.compile(r'^[a-f0-9]{12} default [^\n]+\n')
         pid_smaps_p = re.compile(r'^[0-9a-f]{12}-[0-9a-f]{12} [rwxsp\-]{4} [0-9a-f]{8} [0-9a-f]{2}:[0-9a-f]{2} \d+ [^\n]+\nSize:\s+\d+ \S\S\n')
-        pid_stat_p = re.compile(r'^\d+ \(.{1,15}\) \S \d+ \d+ \d+ \d+ -?\d+ (?:\d+ ){43}\d+$', re.DOTALL)
+        pid_stat_p = re.compile(r'^\d+ \(.+\) \S \d+ \d+ \d+ \d+ -?\d+ (?:\d+ ){43}\d+$', re.DOTALL)
         pid_statm_p = re.compile(r'^\d+ \d+ \d+\s\d+\s\d+\s\d+\s\d+$')
-        pid_status_p = re.compile(r'^Name:\t.+\nUmask:\t\d+\nState:\t.+\nTgid:\t\d+\n')
+        pid_status_p = re.compile(r'^Name:\t.+\n(?:Umask:\t\d+\n)?State:\t.+\nTgid:\t\d+\n')
 
         # scsi_device_info = re.compile(r"^'\w+' '.+' 0x\d+")
         # scsi_scsi_p = re.compile(r'^Attached devices:\nHost: \w+ ')
 
         procmap = {
             buddyinfo_p: 'proc_buddyinfo',
+            cmdline_p: 'proc_cmdline',
             consoles_p: 'proc_consoles',
             cpuinfo_p: 'proc_cpuinfo',
             crypto_p: 'proc_crypto',
@@ -248,6 +252,7 @@ def parse(
             net_packet_p: 'proc_net_packet',
             net_protocols_p: 'proc_net_protocols',
             net_route_p: 'proc_net_route',
+            net_tcp_p: 'proc_net_tcp',
             net_unix_p: 'proc_net_unix',
             net_ipv6_route_p: 'proc_net_ipv6_route',  # before net_dev_mcast
             net_dev_mcast_p: 'proc_net_dev_mcast',    # after net_ipv6_route
