@@ -1,5 +1,7 @@
 """jc - JSON Convert `timedatectl` command output parser
 
+Also supports the `timesync-status` option.
+
 The `epoch_utc` calculated timestamp field is timezone-aware and is only
 available if the `universal_time` field is available.
 
@@ -29,7 +31,24 @@ Schema:
       "system_clock_synchronized":         boolean,
       "systemd-timesyncd.service_active":  boolean,
       "rtc_in_local_tz":                   boolean,
-      "dst_active":                        boolean
+      "dst_active":                        boolean,
+      "server":                            string,
+      "poll_interval":                     string,
+      "leap":                              string,
+      "version":                           integer,
+      "stratum":                           integer,
+      "reference":                         string,
+      "precision":                         string,
+      "root_distance":                     string,
+      "offset":                            float,
+      "offset_unit":                       string,
+      "delay":                             float,
+      "delay_unit":                        string,
+      "jitter":                            float,
+      "jitter_unit":                       string,
+      "packet_count":                      integer,
+      "frequency":                         float,
+      "frequency_unit":                    string
     }
 
 Examples:
@@ -64,12 +83,13 @@ import jc.utils
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.7'
+    version = '1.8'
     description = '`timedatectl status` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     compatible = ['linux']
     magic_commands = ['timedatectl', 'timedatectl status']
+    tags = ['command']
 
 
 __version__ = info.version
@@ -89,11 +109,26 @@ def _process(proc_data):
     """
     bool_list = {'ntp_enabled', 'ntp_synchronized', 'rtc_in_local_tz', 'dst_active',
                  'system_clock_synchronized', 'systemd-timesyncd.service_active'}
+    int_list = {'version', 'stratum', 'packet_count'}
+    float_list = {'offset', 'delay', 'jitter', 'frequency'}
+
+    for key in ['offset', 'delay', 'jitter']:
+        if key in proc_data:
+            proc_data[key + '_unit'] = proc_data[key][-2:]
+
+    if 'frequency' in proc_data:
+        proc_data['frequency_unit'] = proc_data['frequency'][-3:]
 
     for key in proc_data:
         if key in bool_list:
             proc_data[key] = jc.utils.convert_to_bool(proc_data[key])
 
+        if key in int_list:
+            proc_data[key] = jc.utils.convert_to_int(proc_data[key])
+
+        if key in float_list:
+            proc_data[key] = jc.utils.convert_to_float(proc_data[key])
+
     if 'universal_time' in proc_data:
         ts = jc.utils.timestamp(proc_data['universal_time'], format_hint=(7300,))
         proc_data['epoch_utc'] = ts.utc
@@ -119,17 +154,27 @@ def parse(data, raw=False, quiet=False):
     jc.utils.input_type_check(data)
 
     raw_output = {}
+    valid_fields = {
+        'local time', 'universal time', 'rtc time', 'time zone', 'ntp enabled',
+        'ntp synchronized', 'rtc in local tz', 'dst active',
+        'system clock synchronized', 'ntp service',
+        'systemd-timesyncd.service active', 'server', 'poll interval', 'leap',
+        'version', 'stratum', 'reference', 'precision', 'root distance',
+        'offset', 'delay', 'jitter', 'packet count', 'frequency'
+    }
 
     if jc.utils.has_data(data):
 
         for line in filter(None, data.splitlines()):
-            linedata = line.split(':', maxsplit=1)
-            raw_output[linedata[0].strip().lower().replace(' ', '_')] = linedata[1].strip()
+            try:
+                key, val = line.split(':', maxsplit=1)
+                key = key.lower().strip()
+                val = val.strip()
+            except ValueError:
+                continue
 
-            if linedata[0].strip() == 'DST active':
-                break
+            if key in valid_fields:
+                keyname = key.replace(' ', '_')
+                raw_output[keyname] = val
 
-    if raw:
-        return raw_output
-    else:
-        return _process(raw_output)
+    return raw_output if raw else _process(raw_output)
